@@ -11,11 +11,14 @@ function(orderId,
          permId,
          liquidation,
          cumQty,
-         avgPrice) {
+         avgPrice,
+         orderRef,
+         evRule,
+         evMultiplier) {
 
   # special constructor if called with no args
   if(is.null(names(match.call()[-1])))
-    return(do.call('twsExecution', rep(list(NULL),13)))
+    return(do.call('twsExecution', rep(list(NULL),16)))
 
   structure(list(orderId=orderId,
                  clientId=clientId,
@@ -29,7 +32,10 @@ function(orderId,
                  permId=permId,
                  liquidation=liquidation,
                  cumQty=cumQty,
-                 avgPrice=avgPrice),
+                 avgPrice=avgPrice,
+                 orderRef=orderRef,
+                 evRule=evRule,
+                 evMultiplier=evMultiplier),
             class="twsExecution")
 
 }
